import { DBConnector } from '@db';
class DBConsultPool {
    getConnections(connectionParams, instanceType = null) {
        const dbInstance = instanceType ? DBConnector.connect(instanceType) : DBConnector.instance;
        return connectionParams.map((params) => ({
            user: params.externalAuth ? params.connectString : params.user,
            promise: dbInstance.connect(params),
        }));
    }
    fetch(connections, providerInfo) {
        const { method, params = {}, } = providerInfo;
        return connections.map(async (connectionInfo) => {
            const { promise, user } = connectionInfo;
            try {
                const conn = await promise;
                let result = await method(conn, params);
                if (result && Array.isArray(result.rows)) {
                    result = result.rows;
                }
                return { user, result, error: false };
            }
            catch (error) {
                console.error(error.message, { user });
                return { user, result: null, error: error.message };
            }
        });
    }
}
const instance = new DBConsultPool();
export { instance as DBConsultPool };
export default instance;
