import { Request } from '@util';
class License {
    getLicenseUrl() {
        return process.env.LICENSE_URL || '';
    }
    send(endPoint, data) {
        const url = Request.buildUrl(this.getLicenseUrl(), { endPoint });
        return Request.post(url, data);
    }
    getFilterDataParams(params) {
        return {
            requestType: 'FilterData',
            filter: Object.keys(params).map((name) => ({
                name,
                operator: '=',
                value: params[name],
            })),
        };
    }
    getDataSetParams(dataset) {
        return {
            requestType: 'DataSet',
            dataset,
        };
    }
    async auth({ email, password }) {
        return this.send('/getInfoOperador', this.getFilterDataParams({ LOGIN: email, PASSWORD: password })).then((response) => {
            if (response && response.dataset && response.dataset.operador && response.dataset.operador.NRORG) {
                response.dataset.operador.NRORG = response.dataset.operador.NRORG.toString();
            }
            return response;
        });
    }
    getServerByOrganization({ NRORG }) {
        return this.send('/getServeUrl', this.getFilterDataParams({ NRORG }));
    }
    setServerForOrganization({ NRORG, HOST = '', }) {
        return this.send('/saveServeUrl', this.getDataSetParams([{ NRORG, SERVER_DNS: HOST }]));
    }
    async getProductsByOrg({ NRORG }) {
        const result = await this.send('/getOrgProducts', this.getFilterDataParams({ NRORG }));
        if (result && result.dataset && result.dataset.products) {
            return result.dataset.products;
        }
        throw new Error('INVALID_LICENSE_RESPONSE');
    }
}
const instance = new License();
export { instance as License };
export default instance;
