import path from 'path';
import { format as dateFormat } from 'date-fns';
const srcPath = path.dirname(process.argv[1]);
const logoPath = path.join(srcPath, 'assets', 'img', 'logo.jpg');
class PDFTools {
    constructor() {
        this.definitions = {
            logo: {
                filePath: logoPath,
                x: 25,
                y: 20,
                options: { width: 80 },
            },
            boldFont: 'Helvetica-Bold',
            boldFontSize: 14,
            defaultFont: 'Helvetica',
            defaultFontSize: 8,
            page: {
                size: 'A4',
                margins: {
                    top: 25,
                    right: 25,
                    bottom: 25,
                    left: 25,
                },
            },
        };
    }
    addHeaderPage(doc, title, pageIdx, generatedAt = new Date()) {
        const { logo, } = this.definitions;
        const formattedDate = dateFormat(generatedAt, 'dd/MM/yyyy HH:mm');
        doc.image(logo.filePath, logo.x, logo.y, logo.options);
        this.setBoldTextFormat(doc);
        doc.text(title, { align: 'center' });
        this.resetTextFormat(doc);
        doc.text(`Emissão: ${formattedDate}`, 470, 10, { align: 'right' })
            .text(`Página: ${pageIdx}`, 470, 27, { align: 'right' });
    }
    resetTextFormat(doc) {
        const { defaultFont, defaultFontSize } = this.definitions;
        doc.font(defaultFont).fontSize(defaultFontSize);
    }
    setBoldTextFormat(doc) {
        const { boldFont, boldFontSize } = this.definitions;
        doc.font(boldFont).fontSize(boldFontSize);
    }
}
const instance = new PDFTools();
export { instance as PDFTools };
export default instance;
