import { Request } from '@util';
import { Access, Auth } from '@service';
class AccessRoutes {
    register(app) {
        app.post('/access/token', async (req, res) => {
            try {
                const { authorization = '' } = req.headers;
                const { authorized } = await Auth.isValidBasicAuth(authorization);
                if (authorized) {
                    return res.status(200).send(Access.generateToken());
                }
                res.status(500).send({
                    error: 'INVALID_AUTH_CREDENTIALS',
                });
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
        app.post('/access/refresh-token', async (req, res) => {
            try {
                const { refreshToken } = req.body;
                const refreshedToken = Access.refreshToken(refreshToken);
                if (refreshedToken) {
                    return res.status(200).send({ token: refreshedToken });
                }
                res.status(500).send({ error: 'FAIL_REFRESH_TOKEN ' });
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
    }
}
const instance = new AccessRoutes();
export { instance as AccessRoutes };
export default instance;
