import { Login, ProductSetting, UpdaterVersion, Updater, Product, AssistantMonitoring, AssistantControl } from '@service';
import { Request } from '@util';
class ApiRoutes {
    register(app) {
        app.post('/api/login', async (req, res) => {
            try {
                const { agent } = req.headers;
                const agentVersion = req.headers['Agent-Version'] || req.headers['agent-version'];
                const response = await Login.login({ ...Request.getAllParams(req), agent, agentVersion });
                if (response.STATUS) {
                    res.status(200).send(response);
                }
                else {
                    res.status(500).send(response);
                }
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
        app.post('/api/server', async (req, res) => {
            try {
                const response = await Login.setServerForOrganization(Request.getAllParams(req));
                res.send(response);
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
        app.get('/api/product/:devopsId?', async (req, res) => {
            try {
                if (req.params.devopsId) {
                    const allDevopsId = req.params.devopsId.split(',').map((devopsId) => Number(devopsId));
                    if (allDevopsId.some((devopsId) => devopsId === null || Number.isNaN(Number(devopsId)))) {
                        return res.status(500).send({
                            error: 'INVALID_DEVOPS_ID',
                        });
                    }
                    const response = await Product.listByDevopsId(allDevopsId);
                    return res.send(response);
                }
                const response = await Product.list();
                res.send(response);
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
        app.get('/api/product-setting', async (req, res) => {
            try {
                const response = await ProductSetting.getSettingForApi();
                res.send(response);
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
        app.get('/api/updater', async (req, res) => {
            try {
                const productDetail = await Updater.getProductInfo();
                res.status(200).json(productDetail);
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
        app.get('/api/updater-version/download/:version?', async (req, res) => {
            UpdaterVersion.download(Request.getAllParams(req), res);
        });
        app.post('/api/updater-version/download/:version?', async (req, res) => {
            UpdaterVersion.download(Request.getAllParams(req), res);
        });
        app.get('/api/updater-approved-version', async (req, res) => {
            try {
                const response = await UpdaterVersion.getApprovedVersion();
                res.send(response);
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
        app.get('/api/version', async (req, res) => {
            res.status(200).send({
                version: process.env.APPLICATION_VERSION,
                environment: process.env.APP_ENV || 'development',
            });
        });
        app.get('/api/assistant-monitoring', async (req, res) => {
            try {
                const response = await AssistantMonitoring.list();
                res.status(200).send(response);
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
        app.post('/api/encrypt', async (req, res) => {
            try {
                const response = AssistantControl.encrypt(Request.getAllParams(req));
                res.status(200).send(response);
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
        app.get('/api/agents-version/:clientType?', async (req, res) => {
            try {
                const response = await AssistantControl.getAgentsVersion(Request.getAllParams(req));
                res.status(200).send(response);
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
        app.post('/api/install-info', async (req, res) => {
            try {
                const response = await AssistantControl.sendInstallNotification(Request.getAllParams(req));
                res.status(200).send(response);
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
    }
}
const instance = new ApiRoutes();
export { instance as ApiRoutes };
export default instance;
