import { Server as SocketIo } from 'socket.io';
import { SocketTools } from '@util';
import { ContainerPageSocket, SocketPageManager } from '@service/socket-pages';
import { DockerAnalytics } from './docker/DockerAnalytics.js';
class SocketService {
    register(http) {
        SocketService.io = new SocketIo(http, {
            cors: {
                origin: '*',
            },
        });
        this.bindEvents();
        SocketPageManager.setSocketIo(SocketService.io);
        return SocketService.io;
    }
    getSocketIo() {
        return SocketService.io;
    }
    bindEvents() {
        SocketService.io.on('connection', (socket) => {
            const { page } = SocketTools.getQueryParams(socket);
            switch (page) {
                case 'dashboard':
                    socket.join('monitoring');
                    DockerAnalytics.start();
                    break;
                case 'container-management':
                    ContainerPageSocket.join(socket);
                    ContainerPageSocket.join(socket, 'monitoring');
                    ContainerPageSocket.bindEvents(socket);
                    DockerAnalytics.start();
                    break;
                default:
                    socket.join('default-page');
            }
        });
    }
    emit(options, params) {
        const { page, context, userId } = options;
        if (context) {
            SocketPageManager.emitByContext(options, params);
        }
        else if (page) {
            SocketPageManager.emitByPage(options, params);
        }
        else if (userId) {
            this.getSocketIo().fetchSockets().then((sockets) => {
                const targetSocket = sockets.find((socket) => {
                    const { userId: socketUserId } = SocketTools.getQueryParams(socket);
                    return userId === socketUserId;
                });
                if (targetSocket) {
                    targetSocket.emit(options.event, params);
                }
            }).catch((error) => {
                console.error(`Fail to emit for userId ${userId}. Error: ${error.message}`);
            });
        }
    }
}
const instance = new SocketService();
export { instance as SocketService };
export default instance;
