import ms from 'ms';
import { Docker } from '@service';
import { SocketPageManager } from '@service/socket-pages';
class DockerAnalytics {
    stop() {
        DockerAnalytics.active = false;
        if (DockerAnalytics.intervalId) {
            clearInterval(DockerAnalytics.intervalId);
            DockerAnalytics.intervalId = null;
        }
    }
    start() {
        DockerAnalytics.active = true;
        if (!DockerAnalytics.intervalId) {
            this.monitoring().then(() => {
                DockerAnalytics.intervalId = setInterval(this.monitoring.bind(this), DockerAnalytics.timeToMonitoring);
            });
        }
    }
    async monitoring() {
        const allServers = Object.values(Docker.getInstances());
        const connectedSockets = await SocketPageManager.getSocketsInRoom('monitoring');
        const hasConnectedUsers = Array.isArray(connectedSockets) && connectedSockets.length !== 0;
        if (!hasConnectedUsers || !DockerAnalytics.active) {
            this.stop();
            return;
        }
        if (!allServers || (Array.isArray(allServers) && allServers.length === 0)) {
            setTimeout(this.monitoring.bind(this), DockerAnalytics.timeToMonitoring);
            return;
        }
        await Docker.summary({ instance: allServers }).then((result) => {
            SocketPageManager.emitByContext({ context: 'monitoring', event: 'update' }, result);
        }).catch((err) => {
            console.error(err);
        });
    }
}
DockerAnalytics.timeToMonitoring = ms('5s');
DockerAnalytics.active = false;
DockerAnalytics.intervalId = null;
const instance = new DockerAnalytics();
export { instance as DockerAnalytics };
export default instance;
