import { Docker } from '@service';
import { UrlTools } from '@util';
class DockerAssistant {
    async getServerToAddClient(serverHost) {
        if (serverHost) {
            const server = Docker.getInstanceByHost(serverHost);
            if (!server)
                throw new Error(`SERVER_NOT_REGISTERED: ${serverHost}`);
            if (server.deployEnabled === 'N')
                throw new Error(`SERVER_NOT_ENABLED_FOR_USE: ${serverHost}`);
            return {
                name: server.serverName,
                instance: server,
            };
        }
        const { errors, servers } = await Docker.getContainersPerServer({ instance: Object.values(Docker.getInstances()) });
        if (errors && errors.length)
            console.error(errors);
        if (servers && Object.keys(servers).length) {
            const allServers = Object.values(servers);
            const serversDeployEnabled = allServers.filter((server) => server.deployEnabled === 'S');
            if (serversDeployEnabled.length) {
                serversDeployEnabled.sort((serverA, serverB) => {
                    if (serverA.containersCount < serverB.containersCount)
                        return -1;
                    if (serverA.contaienrsCount > serverB.containersCount)
                        return 1;
                    return 0;
                });
                const server = serversDeployEnabled.shift();
                return {
                    name: server.serverName,
                    instance: Docker.getInstance({ serverName: server.serverName }),
                };
            }
            console.error('Without server available to deploy');
        }
        return null;
    }
    async handleClientServer(orgId, serverHost) {
        const { host, protocol = 'http' } = serverHost ? UrlTools.getInfo(serverHost) : { host: '', protocol: 'http' };
        const containerName = `USR_ORG_${orgId}`;
        const { exists, running, error, serverName } = serverHost ? await Docker.statusContainer({
            containerName,
            host,
            protocol,
        }) : { exists: false, running: false, error: '', serverName: '' };
        if (exists && !running) {
            const instance = Docker.getInstance({ serverName });
            await Docker.start({ instance, containerName });
        }
        else if (!exists && !error) {
            const server = await this.getServerToAddClient(serverHost);
            if (server) {
                await Docker.create({ serverName: server.name, containerName, orgId, mode: 'sync' });
            }
            else {
                throw new Error('ERR_GET_SERVER_TO_USE');
            }
            return {
                serverName: server.name,
                host: server.instance.host,
                containerName,
                alreadyExists: false,
            };
        }
        else if (error) {
            console.error('ERROR_CREATE_CONTAINER_ORG', error);
            throw new Error('FAIL_TO_READ_CONTAINER');
        }
        return {
            alreadyExists: true,
        };
    }
}
const instance = new DockerAssistant();
export { instance as DockerAssistant, };
export default instance;
