import axios from 'axios';
import { TemplateManager } from '@template';
class Telegram {
    async sendNotification(templateName, data) {
        try {
            const message = TemplateManager.getMessage(templateName, data);
            const { TGM_INTEGRATION_ENABLED: useTelegram = '', TGM_DEBUG: telegramDebug = '', } = process.env;
            if (useTelegram === 'YES') {
                this.sendMessageRequest(message);
            }
            if (telegramDebug === 'YES') {
                console.log(message);
            }
        }
        catch (err) {
            console.error(err);
        }
    }
    escapeCharacters(message) {
        const escapeMap = {
            escapeDots: (str) => str.replace(/\./g, '\\.'),
            escapeMinus: (str) => str.replace(/-/g, '\\-'),
            escapeGreaterThan: (str) => str.replace(/>/g, '\\>'),
            escapeLessThan: (str) => str.replace(/</g, '\\<'),
        };
        return Object.values(escapeMap).reduce((acc, escapeFunction) => escapeFunction(acc), message);
    }
    async sendMessageRequest(message) {
        const { TGM_API_URI: API_URI, TGM_BOT_ID: BOT_ID, TGM_CHAT_ID: CHAT_ID, TGM_API_TOKEN: TOKEN, } = process.env;
        const config = {
            method: 'get',
            maxBodyLength: Infinity,
            url: `${API_URI}/${BOT_ID}:${TOKEN}/sendMessage`,
            params: {
                chat_id: CHAT_ID,
                text: this.escapeCharacters(message),
                parse_mode: 'MarkdownV2',
                disable_web_page_preview: true,
            },
            headers: {},
        };
        axios.request(config).catch((error) => {
            console.log(error);
        });
    }
}
const instance = new Telegram();
export { instance as Telegram };
export default instance;
